cal.Event (Calendar entry) — amici1

# `cal.Event` (Calendar entry)

Event(id, modified, created, start_date, start_time, end_date, end_time, build_time, build_method, user, assigned_to, owner_type, owner_id, summary, description, access_class, sequence, auto_type, priority, event_type, transparent, room, state)

Master tables : cal.AllEntries (Calendar entries), cal.EntriesByDay (Appointments today), cal.Events (Calendar entries), cal.MyAssignedEvents (Appointments assigned to me), cal.MyEntries (My appointments), cal.MyEntriesToday (My appointments today), cal.MyOverdueAppointments (My overdue appointments), cal.MyUnconfirmedAppointments (My unconfirmed appointments), cal.OneEvent (Calendar entries), cal.OverdueAppointments (Overdue appointments), cal.PublicEntries (Calendar entries)

Slave tables : cal.ConflictingEvents ( ⚔ ), cal.GuestsByEvent (Presences)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Modified (modified) : The time when this database object was last modified.

- Created (created) : The time when this object was created.

- Start date (start_date) : The starting date of this entry. May not be empty.

- Start time (start_time) : The starting time. If this is empty, the entry is considered a all-day entry.

- End Date (end_date) : The ending date of this entry. Leave empty for same-day entries.

- End Time (end_time) : The ending time. If this is before the starting time, and no ending date is given, the entry ends the day after.

- build time (build_time) : Timestamp of the built target file. Contains None if no build hasn’t been called yet.

- Print method (build_method) : See `<lino.core.choicelists.ChoiceListField: build_method>`.

- Responsible user (user) : The responsible user.

- Assigned to (assigned_to) : Another user who is expected to take responsibility for this entry.

- Controlled by (type) (owner_type) : See `<django.db.models.fields.related.ForeignKey: owner_type>`.

- Controlled by (object) (owner_id) : See `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`.

- Short description (summary) : A one-line descriptive text.

- Description (description) : A longer descriptive text.

- Access class (access_class) : Whether this is private, public or between.

- Revision (sequence) : See `<django.db.models.fields.IntegerField: sequence>`.

- No. (auto_type) : Contains the sequence number if this is an automatically generated component. Otherwise this field is empty.

- Priority (priority) : See `<lino.core.choicelists.ChoiceListField: priority>`.

- Calendar entry type (event_type) : The type of this calendar entry.

- Transparent (transparent) : Whether this entry should allow other entries at the same time.

- Room (room) : See `<django.db.models.fields.related.ForeignKey: room>`.

- State (state) : The state of this entry. The state can change according to rules defined by the workflow.

- all day (all_day) : See `lino_xl.lib.cal.models.Event.all_day`.

- When (when_text) : See `lino_xl.lib.cal.models.Event.when_text`.

- When (when_html) : Shows the date and time of the entry with a link that opens all entries on that day.

- Link URL (url) : See `lino_xl.lib.cal.models.Event.url`.

- Reminder (reminder) : See `lino_xl.lib.cal.models.Event.reminder`.

- Calendar (calendar) : See `lino_xl.lib.cal.models.Event.calendar`.

- Name (name_column) : See `lino_xl.lib.cal.models.Event.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.cal.models.Event.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.cal.models.Event.overview`.

- Created (created_natural) : See `lino_xl.lib.cal.models.Event.created_natural`.

- Duration (duration) : See `lino_xl.lib.cal.models.Event.duration`.

Referenced from cal.Guest.event

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
modified | Modified | The time when this database object was last modified.
created | Created | The time when this object was created.
start_date | Start date | The starting date of this entry. May not be empty.
start_time | Start time | The starting time. If this is empty, the entry is considered a all-day entry.
end_date | End Date | The ending date of this entry. Leave empty for same-day entries.
end_time | End Time | The ending time. If this is before the starting time, and no ending date is given, the entry ends the day after.
build_time | build time | Timestamp of the built target file. Contains None if no build hasn’t been called yet.
build_method | Print method |
user | Responsible user | The responsible user.
assigned_to | Assigned to | Another user who is expected to take responsibility for this entry.
owner_type | Controlled by (type) |
owner_id | Controlled by (object) |
summary | Short description | A one-line descriptive text.
description | Description | A longer descriptive text.
access_class | Access class | Whether this is private, public or between.
sequence | Revision |
auto_type | No. | Contains the sequence number if this is an automatically generated component. Otherwise this field is empty.
priority | Priority |
event_type | Calendar entry type | The type of this calendar entry.
transparent | Transparent | Whether this entry should allow other entries at the same time.
room | Room |
state | State | The state of this entry. The state can change according to rules defined by the workflow.
owner | Controlled by |
all_day | all day |
when_text | When |
when_html | When | Shows the date and time of the entry with a link that opens all entries on that day.
url | Link URL |
reminder | Reminder |
calendar | Calendar |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |
created_natural | Created |
duration | Duration |